<template>
  <a-modal
    :title="title"
    :width="1200"
    :visible="visible"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
  >
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :label-col="labelCol" :wrapper-col="wrapperCol" :model="model" :rules="validatorRules">
        <!-- 主表单区域 -->
        <a-row class="form-row" :gutter="16">
          <a-col :lg="8">
            <a-form-model-item label="项目名称" prop="xmmc">
              <a-input v-model="model.xmmc" placeholder="请输入项目名称" />
            </a-form-model-item>
          </a-col>

          <a-col :lg="8">
            <a-form-model-item label="项目编号" prop="xmbh">
              <a-input v-model="model.xmbh" placeholder="请输入项目编号" />
            </a-form-model-item>
          </a-col>

          <a-col :lg="8">
            <a-form-model-item label="负责人" prop="xmfzr">
              <j-select-user-by-dep
                placeholder="请选择项目负责人"
                @ids="(v) => handleChangeUserCommon(v)"
                v-model="model.xmfzr"
                :multi="true"
                :trigger-change="false"
              ></j-select-user-by-dep>
            </a-form-model-item>
          </a-col>

          <a-col :lg="8">
            <a-form-model-item label="报告日期" prop="bgrq">
              <a-date-picker v-model="model.bgrq"  valueFormat="YYYY-MM-DD"  style="width: 100%" placeholder="请选择报告日期" />
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>

    <!--   选择用户  -->
  </a-modal>
</template>

<script>
import JSelectUserByDepModal from '@/components/jeecgbiz/modal/JSelectUserByDepModal'
import { putAction } from '@/api/manage'

export default {
  name: 'ProjectModal1',
  components: {
    JSelectUserByDepModal,
  },
  data() {
    return {
      title: '修改项目信息',
      visible: false,
      form: this.$form.createForm(this),
      userIds: 'admin',
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      validatorRules: {
        xmmc: [{ required: true, message: '项目名称不能为空', trigger: 'blur' }],
        xmbh: [{ required: true, message: '项目编号不能为空', trigger: 'blur' }],
        xmfzr: [{ required: true, message: '项目负责人不能为空', trigger: 'blur' }],
        bgrq: [{ required: true, message: '报告不能为空', trigger: 'blur' }],
      },
      url: {
        edit: '/pro/project/edit',
      },
    }
  },
  watch: {
    /*  model(newName, oldName) {
      if(newName.projectManager_dictText){
        let that = this;
        setTimeout(() => {
           that.userIds  = newName.projectManager_dictText;

        }, 1000)

      }

    }*/
  },
  methods: {
    edit(record) {
      this.form.resetFields()
      this.visible = true
      this.model = Object.assign({}, record)
    },

    handleCancel() {
      this.close()
    },
    handleOk() {
      let that = this
      this.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          //add

          putAction(this.url.edit, that.model)
            .then((res) => {
              that.confirmLoading = false
              if (res.success) {
                that.close()
                that.$message.success(res.message)
                that.$emit('ok', res.result)
                that.close()
              } else {
                that.$message.warning(res.message)
              }
            })
            .finally(() => {
              that.confirmLoading = false
            })
        }
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },

    handleChangeUserCommon(v) {},
  },
}
</script>

<style scoped>
</style>